@@ -30,6 +30,7 @@ const (
 	ansiEscape
 	ansiSubstring
 	ansiControlSequence
+	otherSequence
 	systemSequence
 	oscHyperLink
 	oscParameter
@@ -44,9 +45,12 @@ var DefaultContent = content{
 	style: tcell.StyleDefault,
 }
 
-// EOFContent is "~" only.
+// EOFC is the EOF character.
+const EOFC rune = '~'
+
+// EOFContent is EOFC only.
 var EOFContent = content{
-	mainc: '~',
+	mainc: EOFC,
 	combc: nil,
 	width: 1,
 	style: tcell.StyleDefault.Foreground(tcell.ColorGray),
@@ -187,6 +191,9 @@ func (es *parseState) parseEscapeSequence(mainc rune) bool {
 		case 'P', 'X', '^', '_': // Substrings and commands.
 			es.state = ansiSubstring
 			return true
+		case '(':
+			es.state = otherSequence
+			return true
 		default: // Ignore.
 			es.state = ansiText
 		}
@@ -208,6 +215,9 @@ func (es *parseState) parseEscapeSequence(mainc rune) bool {
 		}
 		es.state = ansiText
 		return true
+	case otherSequence:
+		es.state = ansiEscape
+		return true
 	case systemSequence:
 		switch mainc {
 		case '8':
@@ -220,6 +230,9 @@ func (es *parseState) parseEscapeSequence(mainc rune) bool {
 			// unknown but for compatibility.
 			es.state = ansiControlSequence
 			return true
+		case 0x07:
+			es.state = ansiText
+			return true
 		}
 		log.Printf("invalid char %c", mainc)
 		return true
@@ -244,13 +257,19 @@ func (es *parseState) parseEscapeSequence(mainc rune) bool {
 		es.state = oscURL
 		return true
 	case oscURL:
-		if mainc != 0x1b {
-			es.url.WriteRune(mainc)
+		switch mainc {
+		case 0x1b:
+			es.style = es.style.Url(es.url.String())
+			es.url.Reset()
+			es.state = systemSequence
+			return true
+		case 0x07:
+			es.style = es.style.Url(es.url.String())
+			es.url.Reset()
+			es.state = ansiText
 			return true
 		}
-		es.style = es.style.Url(es.url.String())
-		es.url.Reset()
-		es.state = systemSequence
+		es.url.WriteRune(mainc)
 		return true
 	}
 	switch mainc {
@@ -457,18 +476,22 @@ func StrToContents(str string, tabWidth int) contents {
 	return parseString(str, tabWidth)
 }
 
+type widthPos []int
+
 // ContentsToStr returns a converted string
 // and byte position, as well as the content position conversion table.
-func ContentsToStr(lc contents) (string, map[int]int) {
+func ContentsToStr(lc contents) (string, widthPos) {
 	var buff strings.Builder
-	posCV := make(map[int]int)
+	pos := make(widthPos, 0, len(lc)*4)
 
-	bn := 0
+	i, bn := 0, 0
 	for n, c := range lc {
 		if c.mainc == 0 {
 			continue
 		}
-		posCV[bn] = n
+		for ; i <= bn; i++ {
+			pos = append(pos, n)
+		}
 		mn, err := buff.WriteRune(c.mainc)
 		if err != nil {
 			log.Println(err)
@@ -483,6 +506,16 @@ func ContentsToStr(lc contents) (string, map[int]int) {
 		}
 	}
 	str := buff.String()
-	posCV[bn] = len(lc)
-	return str, posCV
+	for ; i <= bn; i++ {
+		pos = append(pos, len(lc))
+	}
+	return str, pos
+}
+
+// x returns the x position on the screen.
+func (pos widthPos) x(x int) int {
+	if x < len(pos) {
+		return pos[x]
+	}
+	return pos[len(pos)-1]
 }
