@@ -533,6 +533,16 @@ func Test_parseStringHyperlink(t *testing.T) {
 				{width: 1, style: tcell.StyleDefault.Url("http://example.com").UrlId("1"), mainc: rune('k'), combc: nil},
 			},
 		},
+		{
+			name: "testHyperLinkfile",
+			args: args{line: "\x1b]8;;file:///file\afile\x1b]8;;\a", tabWidth: 8},
+			want: contents{
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('f'), combc: nil},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('i'), combc: nil},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('l'), combc: nil},
+				{width: 1, style: tcell.StyleDefault.Url("file:///file"), mainc: rune('e'), combc: nil},
+			},
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -679,43 +689,43 @@ func Test_contentsToStr(t *testing.T) {
 		name  string
 		str   string
 		want1 string
-		want2 map[int]int
+		want2 widthPos
 	}{
 		{
 			name:  "test1",
 			str:   "test",
 			want1: "test",
-			want2: map[int]int{0: 0, 1: 1, 2: 2, 3: 3, 4: 4},
+			want2: widthPos{0, 1, 2, 3, 4},
 		},
 		{
 			name:  "testTab",
 			str:   "t\test",
 			want1: "t\test",
-			want2: map[int]int{0: 0, 1: 1, 2: 8, 3: 9, 4: 10, 5: 11},
+			want2: widthPos{0, 1, 8, 9, 10, 11},
 		},
 		{
 			name:  "testBackSpace",
 			str:   "t\btest",
 			want1: "test",
-			want2: map[int]int{0: 0, 1: 1, 2: 2, 3: 3, 4: 4},
+			want2: widthPos{0, 1, 2, 3, 4},
 		},
 		{
 			name:  "testEscape",
 			str:   "\x1b[40;38;5;82mHello \x1b[30;48;5;82mWorld\x1b[0m",
 			want1: "Hello World",
-			want2: map[int]int{0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5, 6: 6, 7: 7, 8: 8, 9: 9, 10: 10, 11: 11},
+			want2: widthPos{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
 		},
 		{
 			name:  "testMultiByte",
 			str:   "あいうえお倍",
 			want1: "あいうえお倍",
-			want2: map[int]int{0: 0, 3: 2, 6: 4, 9: 6, 12: 8, 15: 10, 18: 12},
+			want2: widthPos{0, 2, 2, 2, 4, 4, 4, 6, 6, 6, 8, 8, 8, 10, 10, 10, 12, 12, 12},
 		},
 		{
 			name:  "testEmojiZWJSequence",
 			str:   string([]rune{'\U0001f468', '\u200d', '\U0001f468', '\u200d', '\U0001f466'}),
 			want1: "👨‍👨‍👦",
-			want2: map[int]int{0: 0, 18: 2},
+			want2: widthPos{0, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2},
 		},
 	}
 	for _, tt := range tests {
